taskgraph

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 1, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Builder

type Builder struct {
	// contains filtered or unexported fields
}

Builder is responsible for building a graph.Graph from a Taskfile.

func New

func New(taskfile *ast.Taskfile) *Builder

func (*Builder) Build

func (b *Builder) Build() *graph.Graph

Build constructs a graph.Graph from the Taskfile, as follows. Each task in the Taskfile is represented as a node in the graph. Each task dependency is captured as a directed edge from the dependent task to the task it depends on. Direct task calls within task commands are also captured as edges.

Jump to